@@ -33,10 +33,11 @@ An array of the enrichment classes which will be used.
 
 =cut
 
-has enrichments =>
+has enrichments => (
   is      => 'rw',
   default => sub { [] },
-  coerce  => sub { instantiate_array(@_) };
+  coerce  => sub { instantiate_array(@_) }
+);
 
 =head1 METHODS
 
@@ -51,7 +52,7 @@ sub enrich {
   my $item    = shift;
   my $request = shift;
   foreach my $enrichment ( @{ $self->enrichments } ) {
-    $request = $enrichment->enrich($item, $request);
+    $request = $enrichment->enrich( $item, $request );
   }
   return $item;
 }
