@@ -3,7 +3,8 @@ use strict;
 use warnings;
 use Moo;
 with 'Articulate::Role::Flow';
-use Articulate::Syntax qw (locspec instantiate instantiate_array);
+use Articulate::Syntax
+  qw (new_location_specification instantiate instantiate_array);
 
 =head1 NAME
 
@@ -21,9 +22,13 @@ Articulate::Flow::LocationSwitch - case switching for location
 
 =head1 DESCRIPTION
 
-This provides a convenient interface to a common branching pattern. When performing actions like C<enrich> and C<augment>, a developer will typically want to make some processes dependant on the location of the content being stored.
+This provides a convenient interface to a common branching pattern.
+When performing actions like C<enrich> and C<augment>, a developer will
+typically want to make some processes dependant on the location of the
+content being stored.
 
-Rather than having to write a 'black box' provider every time, this class provides a standard way of doing it.
+Rather than having to write a 'black box' provider every time, this
+class provides a standard way of doing it.
 
 =head1 METHODS
 
@@ -41,9 +46,13 @@ Rather than having to write a 'black box' provider every time, this class provid
 
   $self->process_method( $verb, $item, $request );
 
-Goes through each of the keys of C<< $self->where >>; if the location of C<$item> matches location specification given (see L<Articulate::LocationSpecification>), then instantiates the value of that key and performs the same verb on the arguments.
+Goes through each of the keys of C<< $self->where >>; if the location
+of C<$item> matches location specification given (see
+L<Articulate::LocationSpecification>), then instantiates the value of
+that key and performs the same verb on the arguments.
 
-If none of the where clauses matched, the otherwise provider, if one is specified, will be used.
+If none of the where clauses matched, the otherwise provider, if one is
+specified, will be used.
 
 =cut
 
@@ -74,8 +83,8 @@ sub process_method {
   my $location = $item->location;
   if ( defined $location ) {
     foreach my $locspec_string ( keys %{ $self->where } ) {
-      my $locspec = locspec $locspec_string;
-      if ( $locspec->matches($location) ) {
+      my $location_specification = new_location_specification $locspec_string;
+      if ( $location_specification->matches($location) ) {
         return $self->_delegate(
           $method => $self->where->{$locspec_string},
           [ $item, @_ ]
