@@ -21,9 +21,13 @@ sub serialise {
   my $self     = shift;
   my $response = shift;
   my $type     = $response->type;
-  if ( $response->data->{$type} and ref $response->data->{$type} eq ref {} and $response->data->{$type}->{schema}->{core}->{file} ) {
-    my $content_type = $response->data->{$type}->{schema}->{core}->{content_type} // $type ;
-    $self->framework->set_content_type ( $content_type );
+  if (  $response->data->{$type}
+    and ref $response->data->{$type} eq ref {}
+    and $response->data->{$type}->{schema}->{core}->{file} )
+  {
+    my $content_type =
+      $response->data->{$type}->{schema}->{core}->{content_type} // $type;
+    $self->framework->set_content_type($content_type);
     my $content = $response->data->{$type}->{content} // '';
     return $content;
   }
