@@ -11,7 +11,7 @@ with 'Articulate::Role::Service';
 sub handle_login_form {
   my $self    = shift;
   my $request = shift;
-  return response 'form/login', { form => {}, };
+  return new_response 'form/login', { form => {}, };
 }
 
 1;
