@@ -15,14 +15,14 @@ sub handle_create_form {
   my $self       = shift;
   my $request    = shift;
   my $user       = $request->user_id;
-  my $location   = loc $request->data->{location};
+  my $location   = new_location $request->data->{location};
   my $permission = $self->authorisation->permitted( $user, write => $location );
 
   if ($permission) {
 
-    return response 'form/create', {
+    return new_response 'form/create', {
       form => {
-        location => loc $location, # as string or arrayref?
+        location => new_location $location, # as string or arrayref?
       },
     };
   }
@@ -36,14 +36,14 @@ sub handle_upload_form {
   my $self       = shift;
   my $request    = shift;
   my $user       = $request->user_id;
-  my $location   = loc $request->data->{location};
+  my $location   = new_location $request->data->{location};
   my $permission = $self->authorisation->permitted( $user, write => $location );
 
   if ($permission) {
 
-    return response 'form/upload', {
+    return new_response 'form/upload', {
       form => {
-        location => loc $location, # as string or arrayref?
+        location => new_location $location, # as string or arrayref?
       },
     };
   }
@@ -56,7 +56,7 @@ sub handle_edit_form {
   my $self    = shift;
   my $request = shift;
 
-  my $location   = loc $request->data->{location};
+  my $location   = new_location $request->data->{location};
   my $user       = $request->user_id;
   my $permission = $self->authorisation->permitted( $user, write => $location );
 
@@ -68,7 +68,7 @@ sub handle_edit_form {
 
     # we don't want to interpret at this point
 
-    return response 'form/edit', {
+    return new_response 'form/edit', {
       raw => {
         meta     => $item->meta,
         content  => $item->content,
@@ -98,7 +98,7 @@ sub handle_delete_form {
     my $item_class = $item->location->[-2];
     $self->augmentation->augment($item) or throw_error 'Internal'; # or throw
 
-    return response 'form/delete', {
+    return new_response 'form/delete', {
       $item_class => {
         schema   => $item->meta->{schema},
         content  => $item->content,
