@@ -21,7 +21,7 @@ This accepts an array of items. pass the item and the request to a series of Sor
 
 Sortations should not mutate the items, however there is no technical barrier to them doing so.
 
-=head1 CONFIGuRATION
+=head1 CONFIGURATION
 
 This can be set up to perform default sorts, however it's fully anticipated that you will need to configure sorts on a per-item basis (e.g. the user may request items with a different sort order).
 
@@ -35,7 +35,7 @@ This is a functional constructor: it returns an Articulate::Sortation object.
 
 sub sortation {
   return __PACKAGE__->new(@_) if @_;
-};
+}
 
 =head1 ATTRIBUTES
 
@@ -45,10 +45,11 @@ An array of the Sortation classes which will be used.
 
 =cut
 
-has sortations =>
+has sortations => (
   is      => 'rw',
   default => sub { [] },
-  coerce  => sub { instantiate_array(@_) };
+  coerce  => sub { instantiate_array(@_) }
+);
 
 =head1 METHODS
 
@@ -59,8 +60,8 @@ Passes the item and request objects to a series of Sortation objects, and return
 =cut
 
 sub sort {
-  my $self    = shift;
-  my $items   = shift;
+  my $self  = shift;
+  my $items = shift;
   foreach my $sortation ( @{ $self->sortations } ) {
     $items = $sortation->sort($items);
   }
