@@ -5,6 +5,33 @@ use warnings;
 use Moo;
 with 'Articulate::Role::Sortation::AllYouNeedIsCmp';
 
+=head1 NAME
+
+Articulate::Sortation::Slug - natural slug sorting
+
+=head1 DESCRIPTION
+
+This implements the L<Articulate::Role::Sortation::AllYouNeedIsCmp>
+role to provide a sorter object which will break up
+
+=head1 METHODS
+
+One method provided here, the rest are as in
+L<Articulate::Role::Sortation::AllYouNeedIsCmp>.
+
+=head3 cmp
+
+  $self->cmp('foo-1', 'bar');    # bar comes before foo
+  $self->cmp('foo-2', 'foo-11'); # 2 comes before 11
+  $self->cmp('foo-2',  'food');  # foo comes before food
+
+Splits into numerical and alphabetical. Sorts the former numerically
+and the latter alphabetically. All characters other than a-z and 0-9
+are treated as 'word breaks' and divide up components but are otherwise
+ignored.
+
+=cut
+
 sub _left { -1 }
 
 sub _right { 1 }
@@ -64,4 +91,16 @@ sub cmp {
   return $left cmp $right;
 }
 
+=head1 SEE ALSO
+
+=over
+
+=item * L<Articulate::Sortation::String>
+
+=item * L<Articulate::Sortation::Numeric>
+
+=back
+
+=cut
+
 1;
