@@ -14,7 +14,7 @@ Articulate::Validation - ensure content is valid before accepting it.
 =head1 DESCRIPTION
 
   use Articulate::Validation;
-  $validation->validate($meta, $content) or throw_error;
+  $validation->validate($item) or throw_error;
 
 Validators should return a true argument if either a) The item is valid, or b) The validator has no opinion on the item.
 
@@ -34,17 +34,17 @@ An arrayref of the classes which provide a validate function, in the order in wh
 
 =cut
 
-has validators =>
+has validators => (
   is      => 'rw',
   default => sub { [] },
-  coerce  => sub { instantiate_array @_ };
+  coerce  => sub { instantiate_array @_ }
+);
 
 sub validate {
-  my $self    = shift;
-  my $meta    = shift;
-  my $content = shift;
-  foreach my $validator (@{ $self->validators }) {
-    my $result = $validator->validate($meta, $content);
+  my $self = shift;
+  my $item = shift;
+  foreach my $validator ( @{ $self->validators } ) {
+    my $result = $validator->validate($item);
     return $result unless $result;
   }
   return 1;
